require 'rarg'

describe RArg do

	it 'raise ParseError without required argument' do
		definition = proc do
			require_arg :r1, :r2
		end
	
		proc{RArg.parse({}, &definition)}.should raise_error(RArg::Error)
		proc{RArg.parse({:r1 => nil}, &definition)}.should raise_error(RArg::Error)
		proc{RArg.parse({:r2 => nil}, &definition)}.should raise_error(RArg::Error)
		proc{RArg.parse({:r1 => nil, :r2 => nil}, &definition)}.should_not raise_error
	end
	
	it 'set default arguments' do
		definition = proc do
			default_arg :d1, 255
		end
	
		re = RArg.parse({}, &definition)
		re[:d1].should == 255
		re = RArg.parse({:d1 => nil}, &definition)
		re[:d1].should be_nil
	end
	
	it 'raise NameError if you try to get named argument that is not defined' do
		re = RArg.parse({}) do
			default_arg :d1
		end
		
		proc{re[:d1]}.should_not raise_error
		proc{re[:unknown]}.should raise_error(RArg::Error)
	end
	
	it 'handle aliases' do
		definition = proc do
			default_arg :a0
			alias_arg :a1, :a0
			alias_arg :a2, :a0
		end
		
		re = RArg.parse({:a1 => 200}, &definition)
		re[:a0].should == 200
		proc{re[:a1]}.should raise_error(RArg::Error)

		re = RArg.parse({:a2 => 200}, &definition)
		re[:a0].should == 200
		proc{re[:a2]}.should raise_error(RArg::Error)
	end
	
	it 'handle aliases and requirements in combination' do
		definition = proc do
			require_arg :r1
			alias_arg :a1, :r1
		end
		
		proc{RArg.parse({:a1 => 200}, &definition)}.should_not raise_error
	end
	
	it "can't set alias from not existing name" do
		definition = proc do
			alias_arg :a1, :a0
			default_arg :a0
		end
		
		proc{RArg.parse({}, &definition)}.should raise_error(RArg::Error)

		
	end



end